@@ -1,15 +1,15 @@
 package WordList::ID::Common::Wikipedia5000;
 
 our $DATE = '2017-12-31'; # DATE
-our $VERSION = '0.001'; # VERSION
+our $VERSION = '0.002'; # VERSION
 
 use WordList;
 our @ISA = qw(WordList);
 
-our %STATS = ("avg_word_len",7.444,"num_words",5000,"num_words_contains_nonword_chars",0,"num_words_contains_whitespace",0,"num_words_contains_unicode",0,"longest_word_len",18,"shortest_word_len",2); # STATS
+our %STATS = ("num_words_contains_nonword_chars",0,"avg_word_len",7.444,"shortest_word_len",2,"num_words",5000,"num_words_contains_whitespace",0,"longest_word_len",18,"num_words_contains_unicode",0); # STATS
 
 1;
-# ABSTRACT: Top 1000 words from Wikipedia Indonesia pages
+# ABSTRACT: Top 5000 words from Wikipedia Indonesia pages
 
 =pod
 
@@ -17,11 +17,11 @@ our %STATS = ("avg_word_len",7.444,"num_words",5000,"num_words_contains_nonword_
 
 =head1 NAME
 
-WordList::ID::Common::Wikipedia5000 - Top 1000 words from Wikipedia Indonesia pages
+WordList::ID::Common::Wikipedia5000 - Top 5000 words from Wikipedia Indonesia pages
 
 =head1 VERSION
 
-This document describes version 0.001 of WordList::ID::Common::Wikipedia5000 (from Perl distribution WordLists-ID-Common), released on 2017-12-31.
+This document describes version 0.002 of WordList::ID::Common::Wikipedia5000 (from Perl distribution WordLists-ID-Common), released on 2017-12-31.
 
 =head1 SYNOPSIS
 
@@ -44,7 +44,7 @@ This document describes version 0.001 of WordList::ID::Common::Wikipedia5000 (fr
 
 =head1 DESCRIPTION
 
-This module contains 1000 most frequently used Indonesian words in Wikipedia
+This module contains 5000 most frequently used Indonesian words in Wikipedia
 Indonesian pages.
 
 Here's how the list is produced: First the Wikipedia Indonesia's XML.bz2 [1] was
@@ -91,7 +91,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/WordLists-
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-WordList-ID-Common>.
+Source repository is at L<https://github.com/perlancar/perl-WordLists-ID-Common>.
 
 =head1 BUGS
 
